@@ -3,13 +3,15 @@ Main interface for outposts service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.outposts import OutpostsClient
+    from mypy_boto3_outposts import OutpostsClient
 
     session = boto3.Session()
 
     client: OutpostsClient = boto3.client("outposts")
     session_client: OutpostsClient = session.client("outposts")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, TYPE_CHECKING, Type
